@@ -850,7 +850,9 @@ void resample3(int *i_perm, int *i_perm_tmp, int n, int *n1)
   
 	// permute step:
 	for (i = n - 1; i > 0; --i) {
-		// j = rand() % (i + 1);
+	  // j = rand() % (i + 1);
+		// printf("%d, ", rand());
+		// printf("%d \n", random_index2(i));
 		j = random_index2(i);
 		temp = i_perm[j];
 		i_perm[j] = i_perm[i];
@@ -870,6 +872,32 @@ void resample3(int *i_perm, int *i_perm_tmp, int n, int *n1)
 	}
 }
 
+int random_index_thread_wrap(int i) {
+  return random_index_thread(i);
+}
+
+
+void resample3_thread(int *permuted_arr, int *i_perm, int *i_perm_tmp, int n, int *n1) {
+  int i, j, temp, tmp0, tmp1;
+  for (i = n - 1; i > 0; --i) {
+    j = permuted_arr[i];
+    temp = i_perm[j];
+    i_perm[j] = i_perm[i];
+    i_perm[i] = temp;
+  }
+  
+  tmp0 = 0;
+  tmp1 = 0;
+  for (i = 0; i < n; i++) {
+    if (i_perm[i] == 1) {
+      i_perm_tmp[tmp0++] = i;
+    }
+    else {
+      i_perm_tmp[*n1 + tmp1] = i;
+      tmp1++;
+    }
+  }
+}
 
 /* Arrange the N elements of ARRAY in random order.
  Only effective if N is much smaller than RAND_MAX;
